/* $Cambridge: hermes/src/prayer/accountd/accountd.h,v 1.4 2009/09/28 10:17:27 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <signal.h>
#include <unistd.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/wait.h>
#include <time.h>
#include <stdarg.h>
#include <stdlib.h>
#include <ctype.h>
#include <strings.h>
#include <errno.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <pwd.h>
#include <grp.h>
#include <sys/stat.h>
#include <sys/time.h>

#include <unistd.h>
#if 0
#include <stropts.h>
#endif
#include <sys/types.h>

#include <termios.h>

extern int errno;

#include "common.h"
#include "lib.h"
#include "config.h"
#include "log.h"
#include "password.h"
#include "fullname.h"
#include "quota.h"
#include "file.h"
#include "mail.h"
#include "filter.h"
#include "checksum.h"
#include "authenticate.h"
